function errors = ZLB_eqm_conditions_distortionary_tax(X,Zss,t_start,a_path,r_path,tau_path,t_g_path,G_path,sigma,psi,epsilon,theta,rhoR,phic,phipi,g,eta,omega1,omega2,util_type,lump,III)

% EXPLANATION
% This code computes the errors for the eqm conditions given X.
% See the equation (1)-(7) in PDF.
% INPUT
% X : eqm objects. If X is a solution, then errors=0.
% Zss : the steady state values.
% tp : when the economy gets away from ZLB
% t_star : t_start is the date that the simulation starts
% a_path : the path of the technology shock
% r_path : the path of the forecasted interest rate
% others are the parameters. See main_ZLB.m
% OUTPUT 
% errors : size(errors) = (# of eqm conditions) * (time length T )
% Before time T, the economy goes back to SS.

Css=Zss(1);
Rss=Zss(7);
Gss=g*Zss(3);
M=length(Zss)-1; % number of the endogenous variables (there is one additional entry in Zss)
if lump == 1;M=M-3;end%lump == 1, drop 8, 9 and 10 in Z.

n=length(X); % Number of variables.

b_g_ss = Zss(8);
tau_ss = Zss(9);
tg_ss=Zss(11);

T=n/M; % time length

% Small check
if floor(T) ~= ceil(T)
    error('fatal wrong length')
end

% reshape Z = z
Z=reshape(X,M,T); % Candidate eqm.

% prepare a box
errors=nan(size(Z,1),size(Z,2));

% First period
a = a_path(t_start);
if lump == 0
    t_g = t_g_path(t_start);
else
    t_g = tau_path(t_start);%when lump == 1, t_g is actually the (exogenous) labor tax rate
end
G = G_path(t_start);

err=ZLB_eqm_one_period_distortionary_tax(  Zss,Z(:,1),Z(:,2),a,r_path(1),t_g,G,sigma,psi,epsilon,theta,rhoR,phic,phipi,tau_ss,eta,omega1,omega2,Rss,Css,b_g_ss,tg_ss,util_type,lump,0);
errors(:,1)=err;

% origianl
% err=ZLB_eqm_one_period_distortionary_tax(Zss,Z(:,1),Z(:,2),a,r_path(1),psi,epsilon,theta,rhoR,phic,phipi,G,Rss,Css);

for ii = 2 : T-1
	rr = r_path(ii);
    a  = a_path(t_start -1 + ii);
    if lump ~= 1
        t_g= t_g_path(t_start -1 + ii);
    else
        t_g= tau_path(t_start -1 + ii);%when lump == 1, t_g is interpreted as tau in the following routine
    end
    G  = G_path(t_start -1 + ii);
    err=ZLB_eqm_one_period_distortionary_tax(Z(:,ii-1),Z(:,ii),Z(:,ii+1),a,rr,t_g,G,sigma,psi,epsilon,theta,rhoR,phic,phipi,tau_ss,eta,omega1,omega2,Rss,Css,b_g_ss,tg_ss,util_type,lump,0);
    errors(:,ii) = err;
end



% In the last period, we delete 5 equilibrium conditions which contain no future endogenous
% variables and replace them by the difference between the date T value of
% 5 variables and their steady state. The 5 variables are variables whose
% time t+1 value does not appear in the time t equilibrium conditions.
if lump == 1
    t_g_path=tau_path;%under lump sum taxes let t_g_path carry the exogenous labor tax rates.
end
errors(:,end)  =ZLB_eqm_one_period_distortionary_tax(Z(:,T-1),Z(:,T),Zss(III),a_path(end),r_path(T),t_g_path(end),G_path(end),sigma,psi,epsilon,theta,rhoR,phic,phipi,tau_ss,eta,omega1,omega2,Rss,Css,b_g_ss,tg_ss,util_type,lump,1);
% make it colum
errors = errors(:);

