function err = ZLB_eqm_one_period_distortionary_tax(Zprevious,Z,Ztomorrow,a,rr,t_g,G,sigma,psi,epsilon,theta,rhoR,phic,phipi,tau_ss,eta,omega1,omega2,Rss,Css,b_g_ss,tg_ss,util_type,lump,last)
% EXPLANATION
% This code computes the eqm condition for a particular period.
% ZLB_eqm_conditions_distortionary_tax.m computes the errors for every period.
% Namely ZLB_eqm_conditions.m stacks the errors computed by this code.
% INPUT
% Zprevious : z(t-1)
% Z : z(t)
% Ztomorrow : z(t+1)
% a : productivity
% tau_ss : the steady state tax on labor
% G : the (actual) government expenditure (g = G/Y)
% b_g : target

% The code starts from here...

% the steady state tax
% tau_ss = 1/3; % the steady state tax rate
nu = 1- (epsilon-1)/epsilon *(1-tau_ss);

% Z(t-1) : Z is the state. Z(t-1) is chosen yesterday. Some of them are
% not used...

%Cm1=Zprevious(1);
pstarm1=Zprevious(2);
%Nm1=Zprevious(3);
%pibarm1=Zprevious(4);
%Km1=Zprevious(5);
%Fm1=Zprevious(6);
Rm1=Zprevious(7);
if lump == 0
    b_gm1 = Zprevious(8);
    Omega_m1 = Zprevious(10);
end

% Z(t) : the choice variable
C=Z(1);
pstar=Z(2); % tak-yun distortion
N=Z(3); % labor
pibar=Z(4); % inflation
K=Z(5); % auxiliary variable
F=Z(6); % auxiliary variable
R=Z(7); % the interest rate

if lump == 0%when taxes are lump sum, then drop last three variables
    b_g = Z(8) ;
    tau = Z(9);
    Omega = Z(10);
else
    tau=t_g;
end

% Z(t+1) : the state tomorrow
Cp1=Ztomorrow(1);
%pstarp1=Ztomorrow(2);
Np1=Ztomorrow(3);
pibarp1=Ztomorrow(4);
Kp1=Ztomorrow(5);
Fp1=Ztomorrow(6);
%Rp1=Ztomorrow(7);
if lump == 0;b_g1=Ztomorrow(8);end
% MU and MRS today
if strcmp(util_type,'separable') % separable u(c,n) = log(c)-n^(1+psi)/(1+psi)
    uc = 1/C;
    mrs = N^psi*C;
    ucp1 = 1/Cp1;
    %mrsp1 = Np1^psi*Cp1;
    st = (1-tau_ss)/(1-tau)*mrs/exp(a); % real marginal cost
else % KPR
    gamma=psi; % NOTE : psi is the subsitution parameter in KPR
    uc = gamma * C^(-gamma*sigma+gamma-1)*(1-N)^((1-gamma)*(1-sigma));
    mrs = (1-gamma)/gamma * C / (1-N);
    ucp1 = gamma * Cp1^(-gamma*sigma+gamma-1)*(1-Np1)^((1-gamma)*(1-sigma));
    st = (1-tau_ss)/(1-tau)*mrs/exp(a); % firm's markup times real marginal cost (assuming 'efficient subsidy')
end
% compute the errors.
err=nan(length(Z),1);

% dynamics of K
err(1)=K- st - theta*(1/(1+rr))*pibarp1^epsilon*Kp1;
% dynamics of F
err(2)=F - 1 - theta*(1/(1+rr))*pibarp1^(epsilon-1)*Fp1;

% price conditions
if last ~= 1
    err(3)=K/F - ((1-theta*pibar^(epsilon-1))/(1-theta))^(1/(1-epsilon));
    err(4)=pstar-1/((1-theta)*((1-theta*pibar^(epsilon-1))/(1-theta))^(epsilon/(epsilon-1))+theta*pibar^epsilon/pstarm1);
else
    err(3)=R-Rss;
    err(4)= C + G  -  pstar * N * exp(a);%when last == 1 and lump == 1, fourth error is resource constraint
    if lump == 0
        err(4)=Omega-b_g_ss;
        err(8)=b_g-b_g_ss;
        err(9)=tau-tau_ss;
    end
end

% Euler eq
err(5)=1-(1/(1+rr))*R*(ucp1/uc)/pibarp1;

if last ~= 1
    % resource constraint
    err(6)= C + G  -  pstar * N * exp(a);
else
    err(6)=pstar-1;
end

% Taylor rule
err(7)=R-Rss*max([1/Rss (Rm1/Rss)^rhoR*((C/Css)^phic*pibar^phipi)^(1-rhoR)]);

if lump == 0
    if last ~=1
        err(8) = tau - tau_ss - eta*(Omega-b_g_ss);
        err(9) = Omega - (b_gm1)^(1-omega1) * Omega_m1^(omega1);
    end
    
    
    % evolutation of Omega
    % very persistent case
    % err(9) = Omega - (b_g_1)^((1-omega1)*(1-omega2)) * Omega_1^(omega1+omega2) * Omega_2^(-omega1*omega2);
    
    
    % Gov.t bc
    Primary_deficit = G - ((tau-nu)*mrs/(1-tau)*N+t_g);
    err(10) = Primary_deficit + Rm1/pibar * b_gm1 - b_g;
end
